import java.awt.*;
/**
 * A rectangular box that "knows" its own location, shape, color, and speed,
 * and can display itself on the screen.
 * Changes since version 15: there was a slight bug in the bouncing code.
 * To wit, it only compared the TOP LEFT corner of the box with the bounds;
 * it should have compare the top left corner with the top and left bounds,
 * and the bottom right corner with the bottom and right bounds.
 * 
 * @author Stephen Bloch
 * @version 16, Sept 13 2006
 */
public class Box
{
    // instance variables
    private Color color;
    private int x, y;
    private int width, height;
    private int dx, dy;

    /**
     * Constructor for objects of class Box
     * 
     * @param color  the Box's fill color
     * @param x      the initial x-coordinate of the top-left corner
     * @param y      the initial y-coordinate of the top-left corner
     * @param width  the box's width in pixels
     * @param height the box's height in pixels
     * @param dx     how many pixels right to move at each move() call
     * @param dy     how many pixels down to move at each move() call
     */
    public Box(Color color, int x, int y, int width, int height, int dx, int dy)
    {
        // initialise instance variables
        this.color = color;
        this.x = x;
        this.y = y;
        this.width = width;
        this.height = height;
        this.dx = dx;
        this.dy = dy;
    }

    /**
     * Display the box on a given graphics context.
     * 
     * @param g2   a Graphics2D context into which to draw.
     */
    public void show (Graphics2D g2) {
        g2.setColor (this.color);
        g2.fill (new Rectangle (this.x, this.y, this.width, this.height));
        }
    
    /**
     * Move the box, bouncing off the walls of a given Rectangle.
     * 
     * @param bounds   the Rectangle within which to bounce
     */
    public void move (Rectangle bounds) {
        this.x += this.dx;
        this.y += this.dy;
        
        if (this.x < bounds.x) {
            // fell off left edge
            dx = Math.abs(dx);
        }
        else if (this.x + this.width > bounds.x + bounds.width) {
            // fell off right edge
            dx = - Math.abs(dx);
        }
        if (this.y < bounds.y) {
            dy = Math.abs(dy);
        }
        else if (this.y + this.height > bounds.y + bounds.height) {
            this.dy = - Math.abs(dy);
        }
       }
}